==> cmsmadesimple-1.5.3.tgz: cms/modules/Search/lang/ext/ru_RU.php <==
<?php
$lang['word'] = '	
Слово';
$lang['count'] = 'Количество';
$lang['confirm_clearstats'] = 'Вы действительно хотите навсегда удалить всю статистику?';
$lang['clear'] = 'Очистить';
$lang['statistics'] = 'Статистика';
$lang['param_action'] = 'Укажите режим работы для модуля. Допустимы значения \'по умолчанию\', и \'ключевые слова\'. Ключевые слова могут быть использованы для создания, разделенного запятыми списка слов, пригодных для использования в мета-теге keywords.';
$lang['param_count'] = 'Этот параметр используется для управления выводом списка ключевых слов, их количество будет ограничено указанным числом';
$lang['param_pageid'] = 'Этот параметр используется только для управления выводом ключевых слов и определяет для какого pageid (отличного от значения по умолчанию) возвращать результаты';
$lang['param_inline'] = 'Если true, то форма поиска заместит тег {search} в блоке контента. Используйте этот параметр, если ваш шаблон содержит несколько блоков контента, и вы не хотите чтобы вывод тега {search} замещал блок {content}. ';
$lang['param_passthru'] = 'Передает именованные параметры указанным модулям. Формат каждого параметра: 
"passtru_MODULENAME_PARAMNAME=\'value\'", например: "passthru_News_detailpage=\'newsdetails\'".';
$lang['param_modules'] = 'Ограничить результаты поиска информацией, проиндексированной в указанных модулях (разделитель - запятая)';
$lang['searchsubmit'] = 'Искать';
$lang['search'] = 'Поиск ';
$lang['param_submit'] = 'Текст, который надо поместить на кнопку отправки запроса';
$lang['param_searchtext'] = 'Текст, который надо поместить в окно ввода для поиска';
$lang['prompt_searchtext'] = 'Текст поиска по умолчанию';
$lang['param_resultpage'] = 'Страница, на которой модуль будет выводить результаты поиска. Это может быть либо алиас страницы, либо её идентификатор. Используется для того, чтобы можно было показывать результаты с другим шаблоном, нежели с использующимся на странице с поисковой формой.';
$lang['description'] = 'Модуль для поиска по сайту и контенту, управляемому другими модулями.';
$lang['reindexallcontent'] = 'Переиндексировать все содержимое';
$lang['reindexcomplete'] = 'Переиндексация завершена!';
$lang['stopwords'] = 'Cлова, не включаемые в поисковые индексы';
$lang['searchresultsfor'] = 'Результаты поиска для запроса ';
$lang['noresultsfound'] = 'По данному запросу ничего не найдено!';
$lang['timetaken'] = 'Затраченное время';
$lang['usestemming'] = 'Использовать морфологический поиск (только для английского)';
$lang['searchtemplate'] = 'Шаблон поиска';
$lang['resulttemplate'] = 'Шаблон результата';
$lang['submit'] = 'Отправить';
$lang['sysdefaults'] = 'Восстановить умолчания';
$lang['searchtemplateupdated'] = 'Шаблон поиска обновлен';
$lang['resulttemplateupdated'] = 'Шаблон результата обновлен';
$lang['restoretodefaultsmsg'] = 'Эта операция восстановит исходные системные шаблоны (ваши изменения будут утеряны). Вы уверены, что хотите продолжить?';
$lang['options'] = 'Настройки';
$lang['eventdesc-SearchInitiated'] = 'Отправляется после того, как начат поиск.';
$lang['eventdesc-SearchCompleted'] = 'Отправляется после того, как поиск завершен.';
$lang['eventdesc-SearchItemAdded'] = 'Отправляется после того, как новый объект проиндексирован.';
$lang['eventdesc-SearchItemDeleted'] = 'Отправляется, когда объект удален из индекса.';
$lang['eventdesc-SearchAllItemsDeleted'] = 'Отправляется, когда все объекты удалены из индекса.';
$lang['eventhelp-SearchInitiated'] = '<p>Отправляется, когда поиск начат</p>
<h4>Параметры</h4>
<ol>
<li>Искомый текст</li>
</ol>
';
$lang['eventhelp-SearchCompleted'] = '<p>Отправляется, когда поиск завершен</p>
<h4>Параметры</h4>
<ol>
<li>Искомый текст</li>
<li>Массив результатов</li>
</ol>
';
$lang['eventhelp-SearchItemAdded'] = '<p>Отправляется, когда новый объект проиндексирован</p>
<h4>Параметры</h4>
<ol>
<li>Имя модуля</li>
<li>Идентификатор объекта</li>
<li>Дополнительное свойства</li>
<li>Контент, который надо проиндексировать и добавить.</li>
</ol>
';
$lang['eventhelp-SearchItemDeleted'] = '<p>Отправляется, когда объект был удален из индекса</p>
<h4>Параметры</h4>
<ol>
<li>Имя модуля</li>
<li>Идентификатор объекта</li>
<li>Дополнительные свойства</li>
</ol>
';
$lang['eventhelp-SearchAllItemsDeleted'] = '<p>Отправляется, когда все объекты были удалены из индекса</p>
<h4>параметры</h4>
<ul>
<li>Нет</li>
</ul>
';
$lang['help'] = '<h3>Как это работает?</h3>

<p>Модуль поиска может искать по содержимому, управляемому "ядром", а также некоторыми зарегистрированными модулями. Вы набираете несколько слов, а он выдаёт соответствующие релевантные результаты.</p>

<h3>Как мне это использовать?</h3>

<p>Простейшим путем будет установка тега {search}. Это вставит вызов модуля в ваш шаблон или страницу, там где вам этого захочется и отобразит форму поискового запроса. Код вызова должен выглядеть так:  <code>{search}</code>.</p>

<h4>Как мне предотвратить индексирование некоторых частей контента?</h4>

<p>Поисковый модуль не будет искать на "неактивных" страницах. Тем не менее, в случае, если используется модуль CustomContent, или какая-либо другая Smarty-логика, с целью показать различный контент для различных групп пользователей, советуем предотвратить  индексирование всей страницы, даже если она активна. Чтобы это сделать, включите следующий тег в любом месте страницы <em><!-- pageAttribute: NotSearchable --></em>. Когда модуль поиска видит такой тег в коде страницы, он полностью исключает её из индекса.</p>

<p>Тег <em><!-- pageAttribute: NotSearchable --></em> также может быть помещен и в шаблон.  Если это сделать, то никакие из страниц, которые его используют не будут проидексированы. Чтобы  переиндексировать эти страницы, следует удалить этот тег.</p>';
$lang['changelog'] = '<ul>
<li>1.1 - Начальный релиз</li>
<li>1.2 - Апрель 2007 (calguy1000)
  <p>Добавлена возможность ограничения результатов поиска определенными модулями и добавлена возможность передачи параметров определенным модулям для того чтобы по-разному форматировать результаты поиска</p>
  <p>Изменено таким образом, что модуль поиска не может быть использован в блоках контента не по умолчанию</p>
</li>
<li>1.3 - Май 2007 (calguy1000)
  <p>Добавлены вызовы SetParameterType</p>
</li>
<li>1.4 - Nov 2007 (calguy1000)
  <p>Adds the keywords action.</p>
  <p>Fixes a problem with using the resultpage parameter to a page that\'s template was dramatically different.</p>
</li>
<li>1.4.1 - Nov 2007 (calguy1000)
  <p>Minor fixes so that php tags, and punctuation characters are not indexed.</p>
  <p>Fix the VisibleToAdminUser method</p>
</li>
<li>1.5 - Mar 2008 (calguy1000)
  <p>Now gather statistics about the top most 50 frequently searched words.</p>
  <p>Addd the ability to display the statistics and clear them from the admin panel.</p>
  <p>Make it easier to style the search button, and its label.</p>
  <p>Now only index active pages</p>
</li>
<li>1.5.1 - July 2008 (calguy1000)
  <p>Minor changes to the template to restore behaviour that was there before 1.5</p>
  <p>Now escape any search term characters that have special meanings in regular expressions</p>
  <p>Minor optimizations and tweaks</p>
</li>
</ul>';
$lang['utma'] = '156861353.4396173478114054000.1212747043.1230326962.1230652456.130';
$lang['utmz'] = '156861353.1230652456.130.48.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.8.2p0.tgz: cms/modules/Search/lang/ext/ru_RU.php <==
<?php
$lang['search_method'] = 'Совместимость с Pretty Urls c помощью метода POST, по умолчанию параметры передаются в GET, чтобы изменить используйте {search search_method="post"} ';
$lang['export_to_csv'] = 'Экспорт в CSV';
$lang['prompt_savephrases'] = 'Поисковый запрос это не отдельные слова';
$lang['word'] = 'Слово';
$lang['count'] = 'Количество';
$lang['confirm_clearstats'] = 'Вы действительно хотите навсегда удалить всю статистику?';
$lang['clear'] = 'Очистить';
$lang['statistics'] = 'Статистика';
$lang['param_action'] = 'Укажите режим работы для модуля. Допустимы значения \'по умолчанию\', и \'ключевые слова\'. Ключевые слова могут быть использованы для создания, разделенного запятыми списка слов, пригодных для использования в мета-теге keywords.';
$lang['param_count'] = 'Этот параметр используется для управления выводом списка ключевых слов, их количество будет ограничено указанным числом';
$lang['param_pageid'] = 'Этот параметр используется только для управления выводом ключевых слов и определяет для какого pageid (отличного от значения по умолчанию) возвращать результаты';
$lang['param_inline'] = 'Если установлено \'true\', то форма поиска заместит тег {search} в блоке контента. Используйте этот параметр, если ваш шаблон содержит несколько блоков контента, и вы не хотите чтобы вывод тега {search} замещал блок {content}. ';
$lang['param_passthru'] = 'Передает именованные параметры указанным модулям. Формат каждого параметра: 
"passtru_MODULENAME_PARAMNAME=\'value\'", например: "passthru_News_detailpage=\'newsdetails\'".';
$lang['param_modules'] = 'Ограничить результаты поиска информацией, проиндексированной в указанных модулях (разделитель - запятая)';
$lang['searchsubmit'] = 'Искать';
$lang['search'] = 'Поиск ';
$lang['param_submit'] = 'Текст, который надо поместить на кнопку отправки запроса';
$lang['param_searchtext'] = 'Текст, который надо поместить в окно ввода для поиска';
$lang['prompt_searchtext'] = 'Текст поиска по умолчанию';
$lang['param_resultpage'] = 'Страница, на которой модуль будет выводить результаты поиска. Это может быть либо алиас страницы, либо её идентификатор. Используется для того, чтобы можно было показывать результаты с другим шаблоном, нежели с использующимся на странице с поисковой формой.';
$lang['prompt_alpharesults'] = 'Сортировать результаты по-алфавиту';
$lang['description'] = 'Модуль для поиска по сайту и контенту, управляемому другими модулями.';
$lang['reindexallcontent'] = 'Переиндексировать все содержимое';
$lang['reindexcomplete'] = 'Переиндексация завершена!';
$lang['stopwords'] = 'Cлова, не включаемые в поисковые индексы';
$lang['searchresultsfor'] = 'Результаты поиска для запроса ';
$lang['noresultsfound'] = 'По данному запросу ничего не найдено!';
$lang['timetaken'] = 'Затраченное время';
$lang['usestemming'] = 'Использовать морфологический поиск (только для английского)';
$lang['searchtemplate'] = 'Шаблон поиска';
$lang['resulttemplate'] = 'Шаблон результата';
$lang['submit'] = 'Отправить';
$lang['sysdefaults'] = 'Восстановить умолчания';
$lang['searchtemplateupdated'] = 'Шаблон поиска обновлен';
$lang['resulttemplateupdated'] = 'Шаблон результата обновлен';
$lang['restoretodefaultsmsg'] = 'Эта операция восстановит исходные системные шаблоны (ваши изменения будут утеряны). Вы уверены, что хотите продолжить?';
$lang['options'] = 'Настройки';
$lang['eventdesc-SearchInitiated'] = 'Отправляется после того, как начат поиск.';
$lang['eventdesc-SearchCompleted'] = 'Отправляется после того, как поиск завершен.';
$lang['eventdesc-SearchItemAdded'] = 'Отправляется после того, как новый объект проиндексирован.';
$lang['eventdesc-SearchItemDeleted'] = 'Отправляется, когда объект удален из индекса.';
$lang['eventdesc-SearchAllItemsDeleted'] = 'Отправляется, когда все объекты удалены из индекса.';
$lang['eventhelp-SearchInitiated'] = '<p>Отправляется, когда поиск начат</p>
<h4>Параметры</h4>
<ol>
<li>Искомый текст</li>
</ol>
';
$lang['eventhelp-SearchCompleted'] = '<p>Отправляется, когда поиск завершен</p>
<h4>Параметры</h4>
<ol>
<li>Искомый текст</li>
<li>Массив результатов</li>
</ol>
';
$lang['eventhelp-SearchItemAdded'] = '<p>Отправляется, когда новый объект проиндексирован</p>
<h4>Параметры</h4>
<ol>
<li>Имя модуля</li>
<li>Идентификатор объекта</li>
<li>Дополнительное свойства</li>
<li>Контент, который надо проиндексировать и добавить.</li>
</ol>
';
$lang['eventhelp-SearchItemDeleted'] = '<p>Отправляется, когда объект был удален из индекса</p>
<h4>Параметры</h4>
<ol>
<li>Имя модуля</li>
<li>Идентификатор объекта</li>
<li>Дополнительные свойства</li>
</ol>
';
$lang['eventhelp-SearchAllItemsDeleted'] = '<p>Отправляется, когда все объекты были удалены из индекса</p>
<h4>параметры</h4>
<ul>
<li>Нет</li>
</ul>
';
$lang['help'] = '<h3>Как это работает?</h3>

<p>Модуль поиска может искать по содержимому, управляемому "ядром", а также некоторыми зарегистрированными модулями. Вы набираете несколько слов, а он выдаёт соответствующие релевантные результаты.</p>

<h3>Как мне это использовать?</h3>

<p>Простейшим путем будет установка тега {search}. Это вставит вызов модуля в ваш шаблон или страницу, там где вам этого захочется и отобразит форму поискового запроса. Код вызова должен выглядеть так:  <code>{search}</code>.</p>

<h4>Как мне предотвратить индексирование некоторых частей контента?</h4>

<p>Поисковый модуль не будет искать на "неактивных" страницах. Тем не менее, в случае, если используется модуль CustomContent, или какая-либо другая Smarty-логика, с целью показать различный контент для различных групп пользователей, советуем предотвратить  индексирование всей страницы, даже если она активна. Чтобы это сделать, включите следующий тег в любом месте страницы <em><!-- pageAttribute: NotSearchable --></em>. Когда модуль поиска видит такой тег в коде страницы, он полностью исключает её из индекса.</p>

<p>Тег <em><!-- pageAttribute: NotSearchable --></em> также может быть помещен и в шаблон.  Если это сделать, то никакие из страниц, которые его используют не будут проидексированы. Чтобы  переиндексировать эти страницы, следует удалить этот тег.</p>';
$lang['utma'] = '156861353.3831803396166608400.1236078336.1242483093.1242487978.79';
$lang['utmz'] = '156861353.1242036083.77.58.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
